==> haskell-dlist-instances-0.1.1.1-106-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-dlist-instances.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 dlist-instances
version:              0.1.1.1
visibility:           public
id:                   dlist-instances-0.1.1.1-6weoJuwITwnDjXN0fS2oEv
key:                  dlist-instances-0.1.1.1-6weoJuwITwnDjXN0fS2oEv
license:              BSD-3-Clause
copyright:            2013 Greg Weber
maintainer:           Greg Weber <greg@gregweber.info>
author:               Greg Weber
homepage:             https://github.com/gregwebs/dlist-instances
synopsis:             Difference lists instances
description:
    See the dlist packages.
    This package is the canonical source for some orphan instances.
    Orphan instances are placed here to avoid dependencies elsewhere.

category:             Data
abi:                  d3c5ec1ba11504f03f975e04efbe457e
exposed:              True
exposed-modules:      Data.DList.Instances
import-dirs:          /usr/lib/ghc-8.10.5/site-local/dlist-instances-0.1.1.1
library-dirs:         /usr/lib/ghc-8.10.5/site-local/dlist-instances-0.1.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.5/dlist-instances-0.1.1.1
hs-libraries:         HSdlist-instances-0.1.1.1-6weoJuwITwnDjXN0fS2oEv
depends:              base-4.14.2.0 dlist-1.0-6OiVjgKlCYDHGRjELdCTkR
haddock-interfaces:
    /usr/share/doc/haskell-dlist-instances/html/dlist-instances.haddock

haddock-html:         /usr/share/doc/haskell-dlist-instances/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-dlist-instances-0.1.1.1-107-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-dlist-instances.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 dlist-instances
version:              0.1.1.1
visibility:           public
id:                   dlist-instances-0.1.1.1-49KrTfEGRyHS4LV0azPz6
key:                  dlist-instances-0.1.1.1-49KrTfEGRyHS4LV0azPz6
license:              BSD-3-Clause
copyright:            2013 Greg Weber
maintainer:           Greg Weber <greg@gregweber.info>
author:               Greg Weber
homepage:             https://github.com/gregwebs/dlist-instances
synopsis:             Difference lists instances
description:
    See the dlist packages.
    This package is the canonical source for some orphan instances.
    Orphan instances are placed here to avoid dependencies elsewhere.

category:             Data
abi:                  60d1881dcdd639fa68982c1f314510e7
exposed:              True
exposed-modules:      Data.DList.Instances
import-dirs:          /usr/lib/ghc-9.0.1/site-local/dlist-instances-0.1.1.1
library-dirs:         /usr/lib/ghc-9.0.1/site-local/dlist-instances-0.1.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/dlist-instances-0.1.1.1
hs-libraries:         HSdlist-instances-0.1.1.1-49KrTfEGRyHS4LV0azPz6
depends:              base-4.15.0.0 dlist-1.0-A8ZakkvDKerBegx9VfkpzR
haddock-interfaces:
    /usr/share/doc/haskell-dlist-instances/html/dlist-instances.haddock

haddock-html:         /usr/share/doc/haskell-dlist-instances/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
